ReflectedInstance class abstract

Constructors

ReflectedInstance(ReflectedType? type, ReflectedClass clazz, Object? reflectee)
const

Properties

clazz → ReflectedClass
final
hashCode → int
The hash code for this object.
no setteroverride
reflectee → Object?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → ReflectedType?
final

Methods

getField(String name) → ReflectedInstance
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override