Reflector class abstract

Implementers

Constructors

Reflector()
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getName(Symbol symbol) → String?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reflectClass(Type clazz) → ReflectedClass?
reflectFunction(Function function) → ReflectedFunction?
reflectFutureOf(Type type) → ReflectedType
reflectInstance(Object object) → ReflectedInstance?
reflectType(Type type) → ReflectedType?
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited