ThrowingReflector class

A Reflector implementation that throws exceptions on all attempts to perform reflection.

Use this in contexts where you know you won't need any reflective capabilities.

Inheritance

Constructors

ThrowingReflector({String errorMessage = defaultErrorMessage})
const

Properties

errorMessage → String
The error message to give the end user when an UnsupportedError is thrown.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getName(Symbol symbol) → String?
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reflectClass(Type clazz) → ReflectedClass
override
reflectFunction(Function function) → ReflectedFunction
override
reflectFutureOf(Type type) → ReflectedType
inherited
reflectInstance(Object object) → ReflectedInstance
override
reflectType(Type type) → ReflectedType
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultErrorMessage → const String