MirrorsReflector class

A Reflector implementation that forwards to dart:mirrors.

Useful on the server, where reflection is supported.

Inheritance

Constructors

MirrorsReflector()
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getName(Symbol symbol) → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reflectClass(Type clazz) → ReflectedClass
override
reflectFunction(Function function) → ReflectedFunction
override
reflectFutureOf(Type type) → ReflectedType
override
reflectInstance(Object object) → ReflectedInstance
override
reflectType(Type type) → ReflectedType
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited